<?php
	/**
		* Update Class
		*
		* @copyright   Copyright (c) 2017, Dmytro Lobov
		* @license     http://opensource.org/licenses/gpl-2.0.php GNU Public License
	*/
	
	
	class Wow_Company_Plugin_Update {
		
		private $plugin_param;
		
		function __construct($plugin_param) {
			
			$this->name = $plugin_param['plugin_name'];
			$this->folder_name = $plugin_param['plugin_folder'];
			$this->file_name = $plugin_param['plugin_file'];
			$this->url = 'http://wow-company.com/update/'.$this->folder_name.'.xml';
			$this->cache = '86400';
			$this->author = $plugin_param['plugin_author'];			
			
			add_action('admin_menu', array($this, 'update_plugin_notifier_menu') ); 
			add_action( 'admin_bar_menu', array($this, 'update_notifier_bar_menu'), 1000 );
			
		}
		
		function update_plugin_notifier_menu() {
			if ( function_exists( 'simplexml_load_string' ) && is_admin() ) { // Stop if simplexml_load_string funtion isn't available
				$xml 			= self::get_latest_plugin_version( $this->cache ); // Get the latest remote XML file on our server
				$plugin_data 	= get_plugin_data( WP_PLUGIN_DIR . '/' . $this->folder_name . '/' . $this->file_name ); // Read plugin current version from the style.css
				
				if ( (string) $xml->latest > (string) $plugin_data['Version'] ) { // Compare current plugin version with the remote XML version
					$menu_name = $this->name;
					
					
					add_dashboard_page( $this->name . ' Plugin Updates', ' <span class="update-plugins count-1"><span class="update-count">New Updates</span></span><br/>'.$menu_name , 'administrator', $this->folder_name.'-update-notifier', array( $this, 'update_notifier' ));
				}
			}			
		}
		
		// Adds an update notification to the WordPress 3.1+ Admin Bar
		function update_notifier_bar_menu() {
			if ( function_exists( 'simplexml_load_string' ) && is_admin() ) { // Stop if simplexml_load_string funtion isn't available
				global $wp_admin_bar, $wpdb;
				
				if ( ! is_super_admin() || ! is_admin_bar_showing() ) // Don't display notification in admin bar if it's disabled or the current user isn't an administrator
				return;
				
				$xml 		= self::get_latest_plugin_version( $this->cache ); // Get the latest remote XML file on our server
				$plugin_data 	= get_plugin_data( WP_PLUGIN_DIR . '/' . $this->folder_name . '/' . $this->file_name ); // Read plugin current version from the main plugin file
				
				if( (string) $xml->latest > (string) $plugin_data['Version'] ) { // Compare current plugin version with the remote XML version
					$wp_admin_bar->add_menu( array( 'id' => 'plugin_update_notifier', 'title' => '<span>' . $this->name . ' <span id="ab-updates">New Updates</span></span>', 'href' => get_admin_url() . 'index.php?page='.$this->folder_name.'-update-notifier' ) );
				}
			}
		}
		
		// The notifier page
		function update_notifier() { 
			$xml 			= self::get_latest_plugin_version( $this->cache ); // Get the latest remote XML file on our server
		$plugin_data 	= get_plugin_data( WP_PLUGIN_DIR . '/' . $this->folder_name . '/' . $this->file_name ); // Read plugin current version from the main plugin file ?>
		
		<style>
			.update-nag { display: none; }
			#instructions {max-width: 670px;}
			h3.title {margin: 30px 0 0 0; padding: 30px 0 0 0; border-top: 1px solid #ddd;}
		</style>
		
		<div class="wrap">
			
			<div id="icon-tools" class="icon32"></div>
			<h2><?php echo $this->name ?> Plugin Updates</h2>
			<div id="message" class="updated below-h2"><p><strong>There is a new version of the <?php echo $this->name; ?> plugin available.</strong> You have version <?php echo $plugin_data['Version']; ?> installed. Update to version <?php echo $xml->latest; ?>.</p></div>
			
			<div id="instructions">
				<h3>Update Download and Instructions</h3>
				<p><strong>Please note:</strong> make a <strong>backup</strong> of the Plugin inside your WordPress installation folder <strong>/wp-content/plugins/<?php echo $this->folder_name; ?>/</strong></p>
				<p>To update the Plugin, login to <a href="http://www.codecanyon.net/?ref=<?php echo $this->author; ?>">CodeCanyon</a>, head over to your <strong>downloads</strong> section and re-download the plugin like you did when you bought it.</p>
				<p>Extract the zip's contents, look for the extracted plugin folder, and after you have all the new files upload them using FTP to the <strong>/wp-content/plugins/<?php echo $this->folder_name; ?>/</strong> folder overwriting the old ones (this is why it's important to backup any changes you've made to the plugin files).</p>
				<p>If you didn't make any changes to the plugin files, you are free to overwrite them with the new ones without the risk of losing any plugins settings, and backwards compatibility is guaranteed.</p>
			</div>
			
			<h3 class="title">Changelog</h3>
			<?php echo $xml->changelog; ?>
			
		</div>
		
		<?php }
		
		
		
		// Get the remote XML file contents and return its data (Version and Changelog)
		// Uses the cached version if available and inside the time interval defined
		function get_latest_plugin_version( $interval ) {
			$notifier_file_url = $this->url;	
			$db_cache_field = $this->folder_name.'-cache';
			$db_cache_field_last_updated = $this->folder_name.'-cache-last-updated';
			$last = get_option( $db_cache_field_last_updated );
			$now = time();
			// check the cache
			if ( ! $last || ( ( $now - $last ) > $interval ) ) {
				// cache doesn't exist, or is old, so refresh it
				if( function_exists( 'curl_init' ) ) { // if cURL is available, use it...
					$ch = curl_init( $notifier_file_url );
					curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
					curl_setopt( $ch, CURLOPT_HEADER, 0 );
					curl_setopt( $ch, CURLOPT_TIMEOUT, 10 );
					$cache = curl_exec( $ch );
					curl_close( $ch );
					} else {
					$cache = file_get_contents( $notifier_file_url ); // ...if not, use the common file_get_contents()
				}
				
				if ( $cache ) {			
					// we got good results	
					update_option( $db_cache_field, $cache );
					update_option( $db_cache_field_last_updated, time() );
				} 
				// read from the cache file
				$notifier_data = get_option( $db_cache_field );
			}
			else {
				// cache file is fresh enough, so read from it
				$notifier_data = get_option( $db_cache_field );
			}
			
			// Let's see if the $xml data was returned as we expected it to.
			// If it didn't, use the default 1.0 as the latest version so that we don't have problems when the remote server hosting the XML file is down
			if( strpos( (string) $notifier_data, '<notifier>' ) === false ) {
				$notifier_data = '<?xml version="1.0" encoding="UTF-8"?><notifier><latest>1.0</latest><changelog></changelog></notifier>';
			}
			
			// Load the remote XML data into a variable and return it
			$xml = simplexml_load_string( $notifier_data ); 
			
			return $xml;
		}
		
		
		
		
		
		
		
		
		
		
		
		
		
	}					